@@ -238,7 +238,7 @@ def main(
                             |_____|                                        
 
 *****************************************************************************
-    """  # noqa: W605
+    """  # noqa: W605, W291
     )
 
     da_loop.loop(*args)
