@@ -1,6 +1,7 @@
+import copy
 import functools
 import time
-from typing import Dict, Union
+from typing import Set
 
 import requests
 
@@ -12,6 +13,8 @@ def conditions_satisfied(
     release: da_types.Release,
     seller_filters: da_types.SellerFilters,
     record_filters: da_types.RecordFilters,
+    country_whitelist: Set[str],
+    country_blacklist: Set[str],
 ):
     """Validates that a given listing satisfies all conditions and filters, including both global filters
     (set via environment variables or via the CLI at runtime) and per-release filters (set in wantlist.json).
@@ -21,10 +24,18 @@ def conditions_satisfied(
         release: the release object, defined by the user, corresponding to the given listing
         seller_filters: the global seller filters
         record_filters: the global record (media & sleeve condition) filters
+        country_whitelist: a list of countries from which we will consider listings as valid
+        country_blacklist: a list of countries from which to consider listings as invalid
 
     Returns: True if the given listing satisfies all conditions, False otherwise.
     """
 
+    # verify country whitelist & blacklist, if used
+    if country_whitelist and listing.seller_ships_from not in country_whitelist:
+        return False
+    if country_blacklist and listing.seller_ships_from in country_blacklist:
+        return False
+
     # verify seller conditions
     if (
         listing.seller_avg_rating is not None
@@ -87,8 +98,12 @@ def time_cache(seconds: int, maxsize=None, typed=False):
     return _decorator
 
 
+class InvalidCurrencyException(Exception):
+    ...
+
+
 @time_cache(seconds=3600)
-def get_currency_rates(base_currency: str) -> Dict[str, float]:
+def get_currency_rates(base_currency: str) -> da_types.CurrencyRates:
     """Get live currency exchange rates (from one base currency). Cached for one hour at a time,
     per currency.
 
@@ -97,6 +112,9 @@ def get_currency_rates(base_currency: str) -> Dict[str, float]:
 
     Returns: a dict containing exchange rates _to_ all major currencies _from_ the given base currency
     """
+
+    if base_currency not in da_types.CURRENCY_CHOICES:
+        raise InvalidCurrencyException(f"{base_currency} is not a supported currency (see `discogs_alert/types.py`).")
     return requests.get(f"https://api.exchangerate.host/latest?base={base_currency}").json().get("rates")
 
 
@@ -111,32 +129,27 @@ def convert_currency(value: float, old_currency: str, new_currency: str) -> floa
     Returns: value in the new currency.
     """
 
-    rates = get_currency_rates(new_currency)
-    return float(value) / rates.get(old_currency)
+    try:
+        return float(value) / get_currency_rates(new_currency)[old_currency]
+    except KeyError:
+        raise InvalidCurrencyException(f"{old_currency} is not a supported currency (see `discogs_alert/types.py`)")
 
 
-def convert_listing_price_currency(
-    listing_price: da_types.ListingPrice, new_currency: str
-) -> Union[da_types.ListingPrice, bool]:
-    """Converts a `ListingPrice` object from its existing currency to another."""
+def convert_listing_price_currency(listing_price: da_types.ListingPrice, new_currency: str) -> da_types.ListingPrice:
+    """Converts a `ListingPrice` object from its existing currency to another, including the shipping price."""
+
+    listing_price = copy.deepcopy(listing_price)
 
     # convert listing price to new currency
     if listing_price.currency != new_currency:
-        try:
-            converted_price = convert_currency(listing_price.value, listing_price.currency, new_currency)
-        except AttributeError:
-            return False
+        listing_price.value = convert_currency(listing_price.value, listing_price.currency, new_currency)
         listing_price.currency = new_currency
-        listing_price.value = converted_price
 
-    # convert listing price shipping to new currency
+    # convert listing shipping price to new currency
     if listing_price.shipping is not None and listing_price.shipping.currency != new_currency:
-        try:
-            converted_shipping = convert_currency(
-                listing_price.shipping.value, listing_price.shipping.currency, new_currency
-            )
-        except AttributeError:
-            return False
-        listing_price.shipping = da_types.Shipping(currency=new_currency, value=converted_shipping)
+        listing_price.shipping = da_types.ShippingPrice(
+            currency=new_currency,
+            value=convert_currency(listing_price.shipping.value, listing_price.shipping.currency, new_currency),
+        )
 
     return listing_price
